# -*- coding: UTF-8 -*-
# Copyright 2014-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""This is the main module of Lino Noi.

.. autosummary::
   :toctree:

   lib


"""

from .setup_info import SETUP_INFO

__version__ = SETUP_INFO['version']

# srcref_url = 'https://gitlab.com/lino-framework/noi/blob/master/%s'
# intersphinx_urls = dict(docs="https://noi.lino-framework.org")
# doc_trees = ['docs']
